==> VariantTools_1.2.2.tar.gz: VariantTools/inst/doc/VariantTools.R <==
### R code from vignette source 'VariantTools.Rnw'

###################################################
### code chunk number 1: <options
###################################################
options(width=72)


###################################################
### code chunk number 2: callVariants
###################################################
library(VariantTools)
p53 <- gmapR:::exonsOnTP53Genome("TP53")
bams <- LungCancerLines::LungCancerBamFiles()
bam <- bams$H1993
tally.param <- VariantTallyParam(gmapR::TP53Genome(), 
                                 readlen = 100L,
                                 high_base_quality = 23L,
                                 which = range(p53),
                                 indels = TRUE)
called.variants <- callVariants(bam, tally.param)


###################################################
### code chunk number 3: callVariants-exonic
###################################################
subsetByOverlaps(called.variants, p53, ignore.strand = TRUE)


###################################################
### code chunk number 4: tallyVariants
###################################################
raw.variants <- tallyVariants(bam, tally.param)


###################################################
### code chunk number 5: qaVariants
###################################################
qa.variants <- qaVariants(raw.variants)


###################################################
### code chunk number 6: callVariants
###################################################
called.variants <- callVariants(qa.variants)


###################################################
### code chunk number 7: VariantQAFilters
###################################################
qa.filters <- VariantQAFilters()


###################################################
### code chunk number 8: VariantQAFilters-summary
###################################################
summary(qa.filters, raw.variants)


###################################################
### code chunk number 9: VariantQAFilters-subset
###################################################
qa.variants <- subsetByFilter(raw.variants, qa.filters)


###################################################
### code chunk number 10: VariantQAFilters-fisherStrandP
###################################################
qa.filters.custom <- VariantQAFilters(fisher.strand.p.value = 1e-4)
summary(qa.filters.custom, raw.variants)


###################################################
### code chunk number 11: VariantQAFilters-compare
###################################################
fs.original <- eval(qa.filters["fisherStrand"], raw.variants) 
fs.custom <- eval(qa.filters.custom["fisherStrand"], raw.variants)
raw.variants[fs.original != fs.custom]


###################################################
### code chunk number 12: VariantQAFilters-mask
###################################################
mask <- GRanges("TP53", IRanges(1010000, width=10000))
qa.variants.masked <- qaVariants(raw.variants, mask = mask)


###################################################
### code chunk number 13: VariantCallingFilters
###################################################
calling.filters <- VariantCallingFilters()
summary(calling.filters, qa.variants)


###################################################
### code chunk number 14: post-filter
###################################################
post.filters <- VariantPostFilters()
summary(post.filters, qa.variants)


###################################################
### code chunk number 15: post-filter-whitelist
###################################################
post.filters <- VariantPostFilters(whitelist = called.variants)
summary(post.filters, qa.variants)


###################################################
### code chunk number 16: callSomaticMutations
###################################################
somatic <- callSampleSpecificVariants(bams$H1993, bams$H2073, tally.param)


###################################################
### code chunk number 17: callSomaticMutations-readCount
###################################################
calling.filters <- VariantCallingFilters(read.count = 3L)
somatic <- callSampleSpecificVariants(bams$H1993, bams$H2073, tally.param,
                                      calling.filters = calling.filters,
                                      power = 0.9, p.value = 0.001)


###################################################
### code chunk number 18: variantGR2VCF
###################################################
vcf <- variantGR2Vcf(called.variants, sample.id = "H1993",
                     project = "VariantTools_Vignette")


###################################################
### code chunk number 19: writeVcf (eval = FALSE)
###################################################
## writeVcf(vcf, "H1993.vcf", index = TRUE)


###################################################
### code chunk number 20: callWildtype
###################################################
pos <- c(called.variants, shift(called.variants, 3))
wildtype <- callWildtype(bam, called.variants, VariantCallingFilters(), 
                         pos = pos, power = 0.85)


###################################################
### code chunk number 21: percentageCalled
###################################################
mean(!is.na(wildtype))

==> VariantTools_1.4.5.tar.gz: VariantTools/inst/doc/VariantTools.R <==
### R code from vignette source 'VariantTools.Rnw'

###################################################
### code chunk number 1: <options
###################################################
options(width=72)


###################################################
### code chunk number 2: callVariants
###################################################
library(VariantTools)
p53 <- gmapR:::exonsOnTP53Genome("TP53") + 1e5
bams <- LungCancerLines::LungCancerBamFiles()
bam <- bams$H1993
tally.param <- TallyVariantsParam(gmapR::TP53Genome(), 
                                  high_base_quality = 23L,
                                  which = range(p53),
                                  indels = TRUE)
called.variants <- callVariants(bam, tally.param)


###################################################
### code chunk number 3: callVariants-exonic
###################################################
subsetByOverlaps(called.variants, p53, ignore.strand = TRUE)


###################################################
### code chunk number 4: tallyVariants
###################################################
raw.variants <- tallyVariants(bam, tally.param, mc.cores=1)


###################################################
### code chunk number 5: qaVariants
###################################################
qa.variants <- qaVariants(raw.variants)
head(softFilterMatrix(qa.variants))


###################################################
### code chunk number 6: callVariants
###################################################
called.variants <- callVariants(qa.variants)


###################################################
### code chunk number 7: VariantQAFilters
###################################################
qa.filters <- VariantQAFilters()


###################################################
### code chunk number 8: VariantQAFilters-summary
###################################################
summary(qa.filters, raw.variants)


###################################################
### code chunk number 9: VariantQAFilters-subset
###################################################
qa.variants <- subsetByFilter(raw.variants, qa.filters)


###################################################
### code chunk number 10: VariantQAFilters-fisherStrandP
###################################################
qa.filters.custom <- VariantQAFilters(fisher.strand.p.value = 1e-4)
summary(qa.filters.custom, raw.variants)


###################################################
### code chunk number 11: VariantQAFilters-compare
###################################################
fs.original <- eval(qa.filters["fisherStrand"], raw.variants) 
fs.custom <- eval(qa.filters.custom["fisherStrand"], raw.variants)
raw.variants[fs.original != fs.custom]


###################################################
### code chunk number 12: VariantQAFilters-mask
###################################################
tally.param@mask <- GRanges("TP53", IRanges(1010000, width=10000))
raw.variants.masked <- tallyVariants(bam, tally.param)


###################################################
### code chunk number 13: VariantCallingFilters
###################################################
calling.filters <- VariantCallingFilters()
summary(calling.filters, qa.variants)


###################################################
### code chunk number 14: post-filter
###################################################
post.filters <- VariantPostFilters()
summary(post.filters, qa.variants)


###################################################
### code chunk number 15: post-filter-whitelist
###################################################
post.filters <- VariantPostFilters(whitelist = called.variants)
summary(post.filters, qa.variants)


###################################################
### code chunk number 16: callSomaticMutations
###################################################
tally.param@bamTallyParam@indels <- FALSE
somatic <- callSampleSpecificVariants(bams$H1993, bams$H2073, tally.param)


###################################################
### code chunk number 17: callSomaticMutations-readCount
###################################################
calling.filters <- VariantCallingFilters(read.count = 3L)
somatic <- callSampleSpecificVariants(bams$H1993, bams$H2073, tally.param,
                                      calling.filters = calling.filters,
                                      power = 0.9, p.value = 0.001)


###################################################
### code chunk number 18: variantGR2VCF
###################################################
sampleNames(called.variants) <- "H1993"
mcols(called.variants) <- NULL
vcf <- asVCF(called.variants)


###################################################
### code chunk number 19: writeVcf (eval = FALSE)
###################################################
## writeVcf(vcf, "H1993.vcf", index = TRUE)


###################################################
### code chunk number 20: callWildtype
###################################################
called.variants <- called.variants[!isIndel(called.variants)]
pos <- c(called.variants, shift(called.variants, 3))
wildtype <- callWildtype(bam, called.variants, VariantCallingFilters(), 
                         pos = pos, power = 0.85)


###################################################
### code chunk number 21: percentageCalled
###################################################
mean(!is.na(wildtype))
